@@ -736,7 +736,7 @@ module ApplicationHelper
   end
 
   def other_formats_links(&block)
-    concat('<p class="other-formats">'.html_safe + l(:label_export_to))
+    concat('<p class="other-formats hide-when-print">'.html_safe + l(:label_export_to))
     yield Redmine::Views::OtherFormatsBuilder.new(self)
     concat('</p>'.html_safe)
   end
